@@ -6,6 +6,7 @@
 
 
 #include "config_file.h"
+#include "status_file.h"
 #include "bundle.h"
 
 typedef void (*progress_callback) (gint percentage, const gchar *message,
@@ -32,6 +33,9 @@ typedef struct {
 	gchar *configpath;
 	RaucConfig *config;
 
+	/* system status (not available when using per-slot status file) */
+	RSystemStatus *system_status;
+
 	GList *progress;
 	progress_callback progress_callback;
 
