@@ -7,6 +7,8 @@
 
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(CMS_ContentInfo, CMS_ContentInfo_free)
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(X509_STORE, X509_STORE_free)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(X509, X509_free)
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(EVP_PKEY, EVP_PKEY_free)
 
 #define R_SIGNATURE_ERROR r_signature_error_quark()
 GQuark r_signature_error_quark(void);
@@ -116,6 +118,15 @@ G_GNUC_WARN_UNUSED_RESULT;
 gboolean cms_is_detached(GBytes *sig, gboolean *detached, GError **error)
 G_GNUC_WARN_UNUSED_RESULT;
 
+/**
+ * Check whether the CMS data is 'enveloped' (i.e. encrypted)
+ *
+ * @param cms raw (ASN.1/DER-encoded) CMS data to check
+ *
+ * @return TRUE if CMS data type is 'enveloped', FALSE otherwise
+ */
+gboolean cms_is_envelopeddata(GBytes *cms_data);
+
 /**
  * Extract manifest included in a signature without verification.
  *
@@ -236,3 +247,43 @@ G_GNUC_WARN_UNUSED_RESULT;
  */
 gboolean cms_get_cert_chain(CMS_ContentInfo *cms, X509_STORE *store, STACK_OF(X509) **verified_chain, GError **error)
 G_GNUC_WARN_UNUSED_RESULT;
+
+/**
+ * Encrypt content for provided recipients
+ *
+ * @param[in] content content to encrypt
+ * @param[in] recipients NULL-terminated array of recipient certificate file
+ *                   name strings.
+ *                   If the file contains multiple concatenated
+ *                   certificates, all will be read.
+ * @param[out] error return location for a GError, or NULL
+ *
+ * @return encrypted CMS data, NULL if failed
+ */
+GBytes *cms_encrypt(GBytes *content, gchar **recipients, GError **error);
+
+/**
+ * Decrypt content with provided keyfile.
+ *
+ * A cert file of the recipient may be passed to speed up finding the right
+ * recipient in the CMS structure (otherwise each must be tried).
+ *
+ * @param[in] content content to decrypt
+ * @param[in] certfile recipient cert file to use for decryption, or NULL
+ * @param[in] keyfile recipient key file to use for decryption
+ * @param[out] error return location for a GError, or NULL
+ *
+ * @return decrypted CMS data, NULL if failed
+ */
+GBytes *cms_decrypt(GBytes *content, const gchar *certfile, const gchar *keyfile, GError **error);
+
+
+/**
+ * Dump content of enevloped CMS.
+ *
+ * @param[in] sig enveloped CMS data to dump
+ * @param[out] error return location for a GError, or NULL
+ *
+ * @return string representation for printing, or NULL on error
+ */
+gchar* envelopeddata_to_string(GBytes *sig, GError **error);
