@@ -43,18 +43,16 @@ G_DEFINE_AUTO_CLEANUP_FREE_FUNC(filedesc, close_preserve_errno, -1)
 
 static inline GSubprocess* r_subprocess_newv(GPtrArray *args, GSubprocessFlags flags, GError **error)
 {
-	gchar *call = g_strjoinv(" ", (gchar**) args->pdata);
+	g_autofree gchar *call = g_strjoinv(" ", (gchar**) args->pdata);
 	g_log(R_LOG_DOMAIN_SUBPROCESS, G_LOG_LEVEL_DEBUG, "launching subprocess: %s", call);
-	g_free(call);
 
 	return g_subprocess_newv((const gchar * const *) args->pdata, flags, error);
 }
 
 static inline GSubprocess * r_subprocess_launcher_spawnv(GSubprocessLauncher *launcher, GPtrArray *args, GError **error)
 {
-	gchar *call = g_strjoinv(" ", (gchar**) args->pdata);
+	g_autofree gchar *call = g_strjoinv(" ", (gchar**) args->pdata);
 	g_log(R_LOG_DOMAIN_SUBPROCESS, G_LOG_LEVEL_DEBUG, "launching subprocess: %s", call);
-	g_free(call);
 
 	return g_subprocess_launcher_spawnv(launcher,
 			(const gchar * const *)args->pdata, error);
@@ -63,6 +61,18 @@ static inline GSubprocess * r_subprocess_launcher_spawnv(GSubprocessLauncher *la
 GSubprocess *r_subprocess_new(GSubprocessFlags flags, GError **error, const gchar *argv0, ...)
 G_GNUC_WARN_UNUSED_RESULT;
 
+/**
+ * Starts a subprocess and waits for it to finish.
+ *
+ * @param args subprocess arguments
+ * @param flags subprocess flags
+ * @param error return location for a GError, or NULL
+ *
+ * @return TRUE on success, FALSE if an error occurred
+ */
+gboolean r_subprocess_runv(GPtrArray *args, GSubprocessFlags flags, GError **error)
+G_GNUC_WARN_UNUSED_RESULT;
+
 #define R_LOG_LEVEL_TRACE 1 << G_LOG_LEVEL_USER_SHIFT
 #define r_trace(...)   g_log(G_LOG_DOMAIN,         \
 		R_LOG_LEVEL_TRACE,    \
@@ -281,7 +291,52 @@ G_GNUC_WARN_UNUSED_RESULT;
  * @param name filename of the symlink to update
  * @param error return location for a GError, or NULL
  *
- * @return the newly alloacted and converted string
+ * @return TRUE if the symlink now points to the given target, FALSE otherwise
  */
 gboolean r_update_symlink(const gchar *target, const gchar *name, GError **error)
 G_GNUC_WARN_UNUSED_RESULT;
+
+/**
+ * Calls syncfs on a given filesystem.
+ *
+ * @param path path on the filesystem to sync
+ * @param error return location for a GError, or NULL
+ *
+ * @return TRUE if the filesystem was synced, FALSE otherwise
+ */
+gboolean r_syncfs(const gchar *path, GError **error)
+G_GNUC_WARN_UNUSED_RESULT;
+
+/**
+ * Create a temporary directory for the fakeroot environment file.
+ *
+ * @param error return location for a GError, or NULL
+ *
+ * @return path to the env file, NULL on error
+ */
+gchar* r_fakeroot_init(GError **error)
+G_GNUC_WARN_UNUSED_RESULT;
+
+/**
+ * Add fakeroot startup arguments to the array.
+ *
+ * The env file needs to be created with r_fakeroot_init first.
+ * Does nothing if the path is NULL.
+ *
+ * @param args the GPtrArray to modify
+ * @param envpath path to the env file
+ */
+void r_fakeroot_add_args(GPtrArray *args, const gchar *envpath);
+
+/**
+ * Removes the temporary directory containing the fakeroot environment file.
+ *
+ * Does nothing if the path is NULL.
+ *
+ * @param envpath path to the env file
+ * @param error return location for a GError, or NULL
+ *
+ * @return TRUE if the cleanup was successful, FALSE otherwise
+ */
+gboolean r_fakeroot_cleanup(const gchar *envpath, GError **error)
+G_GNUC_WARN_UNUSED_RESULT;
