@@ -1949,7 +1949,7 @@ gboolean check_bundle(const gchar *bundlename, RaucBundle **bundle, CheckBundleP
 
 	/* Determine store path for casync, defaults to bundle */
 	if (r_context()->config->store_path) {
-		ibundle->storepath = r_context()->config->store_path;
+		ibundle->storepath = g_strdup(r_context()->config->store_path);
 	} else {
 		gchar *path = ibundle->origpath ?: ibundle->path;
 
