@@ -4,6 +4,8 @@
 
 #include "config_file.h"
 #include "context.h"
+#include "event_log.h"
+#include "status_file.h"
 #include "network.h"
 #include "install.h"
 #include "signature.h"
@@ -139,6 +141,57 @@ static gchar* get_cmdline_bootname(void)
 	return bootname;
 }
 
+static gchar* get_custom_bootname(void)
+{
+	g_autoptr(GSubprocessLauncher) launcher = NULL;
+	g_autoptr(GSubprocess) handle = NULL;
+	g_autoptr(GDataInputStream) datainstream = NULL;
+	g_autoptr(GPtrArray) args_array = NULL;
+	g_autofree gchar *outline = NULL;
+	GError *ierror = NULL;
+	GInputStream *instream;
+	int res;
+
+	args_array = g_ptr_array_new();
+	g_ptr_array_add(args_array, context->config->custom_bootloader_backend);
+	g_ptr_array_add(args_array, (gchar *)("get-current"));
+	g_ptr_array_add(args_array, NULL);
+
+	launcher = g_subprocess_launcher_new(G_SUBPROCESS_FLAGS_STDOUT_PIPE);
+	handle = r_subprocess_launcher_spawnv(launcher, args_array, NULL);
+
+	if (handle == NULL) {
+		g_message("Failed to run custom backend '%s'",
+				context->config->custom_bootloader_backend);
+		return NULL;
+	}
+
+	instream = g_subprocess_get_stdout_pipe(handle);
+	datainstream = g_data_input_stream_new(instream);
+
+	outline = g_data_input_stream_read_line(datainstream, NULL, NULL, &ierror);
+
+	if (ierror) {
+		g_message("Failed to read custom backend output");
+		return NULL;
+	}
+
+	res = g_subprocess_wait_check(handle, NULL, NULL);
+	if (!res) {
+		g_message("Failed to get custom backend output");
+		return NULL;
+	}
+
+	if (!outline) {
+		g_message("Failed to get custom backend bootname: no output");
+		return NULL;
+	}
+
+	g_debug("Resolved custom backend bootname to %s", outline);
+
+	return g_steal_pointer(&outline);
+}
+
 /**
  * Launches a handler and obtains variables from output by looking for
  * 'RAUC_<SOMETHING>=value' lines to put them into a key/value store (GHashTable).
@@ -314,6 +367,23 @@ static gboolean r_context_configure_target(GError **error)
 		}
 	}
 
+	/* load system status if central status file is available */
+	if (g_strcmp0(context->config->statusfile_path, "per-slot") != 0) {
+		g_clear_pointer(&context->system_status, r_system_status_free);
+		context->system_status = g_new0(RSystemStatus, 1);
+		if (!r_system_status_load(context->config->statusfile_path, context->system_status, &ierror)) {
+			g_message("Failed to load system status: %s", ierror->message);
+			g_clear_error(&ierror);
+		}
+	}
+
+	/* set up logging */
+	for (GList *l = context->config->loggers; l != NULL; l = l->next) {
+		REventLogger* logger = l->data;
+
+		r_event_log_setup_logger(logger);
+	}
+
 	if (context->config->system_variant_type == R_CONFIG_SYS_VARIANT_DTB) {
 		gchar *compatible = get_system_dtb_compatible(&ierror);
 		if (!compatible) {
@@ -351,6 +421,10 @@ static gboolean r_context_configure_target(GError **error)
 		context->bootslot = get_cmdline_bootname();
 	}
 
+	if (context->bootslot == NULL && (g_strcmp0(context->config->system_bootloader, "custom") == 0)) {
+		context->bootslot = get_custom_bootname();
+	}
+
 	g_clear_pointer(&context->boot_id, g_free);
 	g_clear_pointer(&context->machine_id, g_free);
 
@@ -799,6 +873,8 @@ void r_context_clean(void)
 
 		g_clear_pointer(&context->config, free_config);
 
+		g_clear_pointer(&context->system_status, r_system_status_free);
+
 		g_clear_pointer(&context, g_free);
 	}
 }
