@@ -84,6 +84,10 @@ static gboolean parse_image(GKeyFile *key_file, const gchar *group, RaucImage **
 		}
 	}
 
+	g_key_file_remove_key(key_file, group, "version", NULL);
+	g_key_file_remove_key(key_file, group, "description", NULL);
+	g_key_file_remove_key(key_file, group, "build", NULL);
+
 	iimage->adaptive = g_key_file_get_string_list(key_file, group, "adaptive", NULL, NULL);
 	g_key_file_remove_key(key_file, group, "adaptive", NULL);
 
@@ -246,6 +250,7 @@ static gboolean parse_manifest(GKeyFile *key_file, RaucManifest **manifest, GErr
 	if (raucm->handler_args && !raucm->handler_name) {
 		g_set_error(error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_PARSE,
 				"Setting 'args' requires a full custom handler to be defined under 'filename' in group '[handler]'.");
+		return FALSE;
 	}
 	if (!check_remaining_keys(key_file, "handler", &ierror)) {
 		g_propagate_error(error, ierror);
