@@ -562,7 +562,7 @@ static void start_configure(struct RaucNBDContext *ctx, struct RaucNBDTransfer *
 
 	/* only read from the client on the first try */
 	if (!ctx->url) {
-		GStrv info_headers; /* array of strings such as 'Foo: bar' */
+		GStrv info_headers = NULL; /* array of strings such as 'Foo: bar' */
 
 		res = r_read_exact(ctx->sock, (guint8*)data, xfer->request.len, NULL);
 		g_assert_true(res);
@@ -650,19 +650,25 @@ static void start_request(struct RaucNBDContext *ctx, struct RaucNBDTransfer *xf
 static gboolean finish_read(struct RaucNBDContext *ctx, struct RaucNBDTransfer *xfer)
 {
 	gboolean res = FALSE;
-	CURLcode code;
-	long response_code = 0;
 
 	if (!xfer->done) { /* retry */
 		res = TRUE;
 		goto out;
 	}
 
-	code = curl_easy_getinfo(xfer->easy, CURLINFO_RESPONSE_CODE, &response_code);
-	if (code != CURLE_OK)
-		g_error("unexpected error from curl_easy_getinfo in %s", G_STRFUNC);
-	if (response_code != 206)
-		g_error("unexpected HTTP response code %ld from curl_easy_getinfo in %s", response_code, G_STRFUNC);
+	/* If reply is considered error-free so far, check that response_code
+	 * is actually 206 */
+	if (xfer->reply.error == 0) {
+		long response_code = 0;
+		CURLcode code = curl_easy_getinfo(xfer->easy, CURLINFO_RESPONSE_CODE, &response_code);
+		if (code != CURLE_OK)
+			g_error("unexpected error from curl_easy_getinfo in %s", G_STRFUNC);
+
+		if (response_code != 206) {
+			g_warning("unexpected HTTP response code %ld from curl_easy_getinfo in %s", response_code, G_STRFUNC);
+			xfer->reply.error = GUINT32_TO_BE(5); /* NBD_EIO */
+		}
+	}
 
 	if (!r_write_exact(ctx->sock, (guint8*)&xfer->reply, sizeof(xfer->reply), NULL))
 		g_error("failed to send nbd read reply header");
@@ -1244,6 +1250,16 @@ gboolean r_nbd_stop_server(RaucNBDServer *nbd_srv, GError **error)
 	g_message("nbd server stopping");
 
 	if (nbd_srv->sock >= 0) {
+		struct nbd_request request = {0};
+
+		/* If socket is still active, manually invoke NBD_CMD_DISC
+		 * first, to trigger a graceful shutdown of the NBD server. */
+		request.magic = GUINT32_TO_BE(NBD_REQUEST_MAGIC);
+		request.type = GUINT32_TO_BE(NBD_CMD_DISC);
+		request.len = 0;
+		if (!r_write_exact(nbd_srv->sock, (guint8*)&request, sizeof(request), NULL))
+			g_error("failed to send nbd disconnect request");
+
 		g_close(nbd_srv->sock, NULL);
 		nbd_srv->sock = -1;
 	}
