@@ -11,6 +11,7 @@
 #include "mark.h"
 #include "rauc-installer-generated.h"
 #include "service.h"
+#include "status_file.h"
 #include "utils.h"
 
 GMainLoop *service_loop = NULL;
@@ -81,6 +82,7 @@ static gboolean r_on_handle_install_bundle(
 {
 	RaucInstallArgs *args = install_args_new();
 	g_auto(GVariantDict) dict = G_VARIANT_DICT_INIT(arg_args);
+	g_autoptr(GVariant) dict_rest = NULL;
 	GVariantIter iter;
 	gchar *key;
 	g_autofree gchar *message = NULL;
@@ -108,7 +110,8 @@ static gboolean r_on_handle_install_bundle(
 	convert_dict_to_bundle_access_args(&dict, &args->access_args);
 
 	/* Check for unhandled keys */
-	g_variant_iter_init(&iter, g_variant_dict_end(&dict));
+	dict_rest = g_variant_dict_end(&dict);
+	g_variant_iter_init(&iter, dict_rest);
 	while (g_variant_iter_next(&iter, "{sv}", &key, NULL)) {
 		message = g_strdup_printf("Unsupported key: %s", key);
 		g_free(key);
@@ -117,6 +120,8 @@ static gboolean r_on_handle_install_bundle(
 		goto out;
 	}
 
+	r_config_file_modified_check();
+
 	r_installer_set_operation(r_installer, "installing");
 	g_dbus_interface_skeleton_flush(G_DBUS_INTERFACE_SKELETON(r_installer));
 	res = install_run(args);
@@ -281,7 +286,7 @@ static GVariant* convert_slot_status_to_dict(RaucSlot *slot)
 	RaucSlotStatus *slot_state = NULL;
 	GVariantDict dict;
 
-	load_slot_status(slot);
+	r_slot_status_load(slot);
 	slot_state = slot->status;
 
 	g_variant_dict_init(&dict, NULL);
@@ -414,6 +419,8 @@ static gboolean r_on_handle_get_slot_status(RInstaller *interface,
 		return TRUE;
 	}
 
+	r_config_file_modified_check();
+
 	slotstatus = create_slotstatus_array(&ierror);
 	if (!slotstatus) {
 		g_dbus_method_invocation_return_gerror(invocation, ierror);
@@ -495,15 +502,10 @@ static void send_progress_callback(gint percentage,
 		const gchar *message,
 		gint nesting_depth)
 {
-	GVariant **progress_update;
 	GVariant *progress_update_tuple;
 
-	progress_update = g_new(GVariant*, 3);
-	progress_update[0] = g_variant_new_int32(percentage);
-	progress_update[1] = g_variant_new_string(message);
-	progress_update[2] = g_variant_new_int32(nesting_depth);
+	progress_update_tuple = g_variant_new("(isi)", percentage, message, nesting_depth);
 
-	progress_update_tuple = g_variant_new_tuple(progress_update, 3);
 	r_installer_set_progress(r_installer, progress_update_tuple);
 	g_dbus_interface_skeleton_flush(G_DBUS_INTERFACE_SKELETON(r_installer));
 }
