@@ -75,17 +75,16 @@ out:
 	return slot;
 }
 
-RaucSlot *r_slot_find_by_bootname(GHashTable *slots, const gchar *bootname)
+RaucSlot *r_slot_get_booted(GHashTable *slots)
 {
 	GHashTableIter iter;
 	RaucSlot *slot;
 
 	g_return_val_if_fail(slots, NULL);
-	g_return_val_if_fail(bootname, NULL);
 
 	g_hash_table_iter_init(&iter, slots);
 	while (g_hash_table_iter_next(&iter, NULL, (gpointer*) &slot)) {
-		if (g_strcmp0(slot->bootname, bootname) == 0) {
+		if (slot->state == ST_BOOTED) {
 			goto out;
 		}
 	}
