@@ -14,6 +14,7 @@
 #include "mount.h"
 #include "signature.h"
 #include "update_handler.h"
+#include "update_utils.h"
 #include "emmc.h"
 #include "mbr.h"
 #include "gpt.h"
@@ -60,65 +61,6 @@ static gboolean check_image_size(int fd, const RaucImage *image, GError **error)
 	return TRUE;
 }
 
-/* the fd will only live as long as the returned output stream */
-static GUnixOutputStream* open_slot_device(RaucSlot *slot, int *fd, GError **error)
-{
-	GUnixOutputStream *outstream = NULL;
-	int fd_out;
-
-	g_return_val_if_fail(slot, NULL);
-	g_return_val_if_fail(error == NULL || *error == NULL, NULL);
-
-	fd_out = g_open(slot->device, O_WRONLY | O_EXCL);
-
-	if (fd_out == -1) {
-		g_set_error(error, R_UPDATE_ERROR, R_UPDATE_ERROR_FAILED,
-				"Opening output device %s failed: %s", slot->device, strerror(errno));
-		return NULL;
-	}
-
-	outstream = G_UNIX_OUTPUT_STREAM(g_unix_output_stream_new(fd_out, TRUE));
-	if (outstream == NULL) {
-		g_set_error(error, R_UPDATE_ERROR, R_UPDATE_ERROR_FAILED,
-				"Failed to create stream for output device %s", slot->device);
-		return NULL;
-	}
-
-	if (fd != NULL)
-		*fd = fd_out;
-
-	return outstream;
-}
-
-static GUnixInputStream* open_file_as_unix_input_stream(const gchar *filename, int *fd, GError **error)
-{
-	GUnixInputStream *instream = NULL;
-	int fd_out;
-
-	g_return_val_if_fail(filename, NULL);
-	g_return_val_if_fail(error == NULL || *error == NULL, NULL);
-
-	fd_out = g_open(filename, O_RDONLY);
-	if (fd_out < 0) {
-		int err = errno;
-		g_set_error(error, G_IO_ERROR, g_io_error_from_errno(err),
-				"Failed to open file %s: %s", filename, g_strerror(err));
-		return NULL;
-	}
-
-	instream = G_UNIX_INPUT_STREAM(g_unix_input_stream_new(fd_out, TRUE));
-	if (instream == NULL) {
-		g_set_error(error, R_UPDATE_ERROR, R_UPDATE_ERROR_FAILED,
-				"Failed to create stream for file %s", filename);
-		return NULL;
-	}
-
-	if (fd != NULL)
-		*fd = fd_out;
-
-	return instream;
-}
-
 #if ENABLE_EMMC_BOOT_SUPPORT == 1
 static gboolean clear_slot(RaucSlot *slot, GError **error)
 {
@@ -127,7 +69,7 @@ static gboolean clear_slot(RaucSlot *slot, GError **error)
 	g_autoptr(GOutputStream) outstream = NULL;
 	gint write_count = 0;
 
-	outstream = G_OUTPUT_STREAM(open_slot_device(slot, NULL, &ierror));
+	outstream = G_OUTPUT_STREAM(r_open_unix_output_stream(slot->device, NULL, &ierror));
 	if (outstream == NULL) {
 		g_propagate_error(error, ierror);
 		return FALSE;
@@ -239,45 +181,6 @@ static gboolean ubifs_ioctl(RaucImage *image, int fd, GError **error)
 	return TRUE;
 }
 
-static gssize copy_with_progress(GOutputStream *out_stream, GInputStream *image_stream,
-		goffset image_size, GError **error)
-{
-	GError *ierror = NULL;
-	gsize out_size = 0;
-	goffset sum_size = 0;
-	gint last_percent = -1, percent;
-	gchar buffer[8192];
-	gssize in_size;
-
-	do {
-		gboolean ret;
-
-		in_size = g_input_stream_read(image_stream,
-				buffer, 8192, NULL, &ierror);
-		if (in_size == -1) {
-			g_propagate_error(error, ierror);
-			return -1;
-		}
-		ret = g_output_stream_write_all(out_stream, buffer,
-				in_size, &out_size, NULL, &ierror);
-		if (!ret) {
-			g_propagate_error(error, ierror);
-			return -1;
-		}
-
-		sum_size += out_size;
-
-		percent = sum_size * 100 / image_size;
-		/* emit progress info (but only when in progress context) */
-		if (r_context()->progress && percent != last_percent) {
-			last_percent = percent;
-			r_context_set_step_percentage("copy_image", percent);
-		}
-	} while (out_size);
-
-	return sum_size;
-}
-
 static gboolean splice_with_progress(GUnixInputStream *image_stream,
 		GUnixOutputStream *out_stream, GError **error)
 {
@@ -330,7 +233,7 @@ static gboolean splice_file_to_outstream(const gchar *filename,
 	g_return_val_if_fail(out_stream, FALSE);
 	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
 
-	image_stream = open_file_as_unix_input_stream(filename, NULL, &ierror);
+	image_stream = r_open_unix_input_stream(filename, NULL, &ierror);
 	if (image_stream == NULL) {
 		g_propagate_prefixed_error(
 				error,
@@ -375,13 +278,21 @@ static gboolean splice_file_to_process_stdin(const gchar *filename, GSubprocess
 static gboolean copy_raw_image(RaucImage *image, GUnixOutputStream *outstream, gsize len_header_last, GError **error)
 {
 	GError *ierror = NULL;
-	gssize size;
 	goffset seeksize;
-	g_autoptr(GFile) srcimagefile = g_file_new_for_path(image->filename);
-	int out_fd = g_unix_output_stream_get_fd(outstream);
+	g_autoptr(GFile) srcimagefile = NULL;
+	int out_fd = -1;
 	g_autofree void *header = NULL;
+	g_autoptr(GInputStream) instream = NULL;
 
-	g_autoptr(GInputStream) instream = G_INPUT_STREAM(g_file_read(srcimagefile, NULL, &ierror));
+	g_return_val_if_fail(image, FALSE);
+	g_return_val_if_fail(image->checksum.size >= 0, FALSE);
+	g_return_val_if_fail(outstream, FALSE);
+	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
+
+	srcimagefile = g_file_new_for_path(image->filename);
+	out_fd = g_unix_output_stream_get_fd(outstream);
+
+	instream = G_INPUT_STREAM(g_file_read(srcimagefile, NULL, &ierror));
 	if (instream == NULL) {
 		g_propagate_prefixed_error(error, ierror,
 				"Failed to open file for reading: ");
@@ -411,10 +322,9 @@ static gboolean copy_raw_image(RaucImage *image, GUnixOutputStream *outstream, g
 		}
 	}
 
-	size = copy_with_progress(G_OUTPUT_STREAM(outstream), instream, image->checksum.size, &ierror);
-	if (size == -1) {
+	if (!r_copy_stream_with_progress(instream, G_OUTPUT_STREAM(outstream), image->checksum.size, &ierror)) {
 		g_propagate_prefixed_error(error, ierror,
-				"Failed splicing data: ");
+				"Failed to copy data: ");
 		return FALSE;
 	}
 
@@ -728,7 +638,7 @@ static gboolean copy_raw_image_to_dev(RaucImage *image, RaucSlot *slot, GError *
 
 	/* open */
 	g_message("opening slot device %s", slot->device);
-	outstream = open_slot_device(slot, NULL, &ierror);
+	outstream = r_open_unix_output_stream(slot->device, NULL, &ierror);
 	if (outstream == NULL) {
 		res = FALSE;
 		g_propagate_error(error, ierror);
@@ -1036,7 +946,6 @@ raw_copy:
 
 static gboolean ubifs_format_slot(RaucSlot *dest_slot, GError **error)
 {
-	g_autoptr(GSubprocess) sproc = NULL;
 	GError *ierror = NULL;
 	gboolean res = FALSE;
 	g_autoptr(GPtrArray) args = g_ptr_array_new_full(3, g_free);
@@ -1046,16 +955,7 @@ static gboolean ubifs_format_slot(RaucSlot *dest_slot, GError **error)
 	g_ptr_array_add(args, g_strdup(dest_slot->device));
 	g_ptr_array_add(args, NULL);
 
-	sproc = r_subprocess_newv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
-	if (sproc == NULL) {
-		g_propagate_prefixed_error(
-				error,
-				ierror,
-				"failed to start mkfs.ubifs: ");
-		goto out;
-	}
-
-	res = g_subprocess_wait_check(sproc, NULL, &ierror);
+	res = r_subprocess_runv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
 	if (!res) {
 		g_propagate_prefixed_error(
 				error,
@@ -1070,7 +970,6 @@ out:
 
 static gboolean ext4_resize_slot(RaucSlot *dest_slot, GError **error)
 {
-	g_autoptr(GSubprocess) sproc = NULL;
 	GError *ierror = NULL;
 	gboolean res = FALSE;
 	g_autoptr(GPtrArray) args = g_ptr_array_new_full(3, g_free);
@@ -1079,16 +978,7 @@ static gboolean ext4_resize_slot(RaucSlot *dest_slot, GError **error)
 	g_ptr_array_add(args, g_strdup(dest_slot->device));
 	g_ptr_array_add(args, NULL);
 
-	sproc = r_subprocess_newv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
-	if (sproc == NULL) {
-		g_propagate_prefixed_error(
-				error,
-				ierror,
-				"Failed to start resize2fs: ");
-		goto out;
-	}
-
-	res = g_subprocess_wait_check(sproc, NULL, &ierror);
+	res = r_subprocess_runv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
 	if (!res) {
 		g_propagate_prefixed_error(
 				error,
@@ -1103,7 +993,6 @@ out:
 
 static gboolean ext4_format_slot(RaucSlot *dest_slot, GError **error)
 {
-	g_autoptr(GSubprocess) sproc = NULL;
 	GError *ierror = NULL;
 	gboolean res = FALSE;
 	g_autoptr(GPtrArray) args = g_ptr_array_new_full(4, g_free);
@@ -1118,16 +1007,7 @@ static gboolean ext4_format_slot(RaucSlot *dest_slot, GError **error)
 	g_ptr_array_add(args, g_strdup(dest_slot->device));
 	g_ptr_array_add(args, NULL);
 
-	sproc = r_subprocess_newv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
-	if (sproc == NULL) {
-		g_propagate_prefixed_error(
-				error,
-				ierror,
-				"failed to start mkfs.ext4: ");
-		goto out;
-	}
-
-	res = g_subprocess_wait_check(sproc, NULL, &ierror);
+	res = r_subprocess_runv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
 	if (!res) {
 		g_propagate_prefixed_error(
 				error,
@@ -1186,7 +1066,6 @@ static gchar* vfat_label_generator(const gchar *name)
 
 static gboolean vfat_format_slot(RaucSlot *dest_slot, GError **error)
 {
-	g_autoptr(GSubprocess) sproc = NULL;
 	GError *ierror = NULL;
 	gboolean res = FALSE;
 	g_autoptr(GPtrArray) args = g_ptr_array_new_full(4, g_free);
@@ -1197,16 +1076,7 @@ static gboolean vfat_format_slot(RaucSlot *dest_slot, GError **error)
 	g_ptr_array_add(args, g_strdup(dest_slot->device));
 	g_ptr_array_add(args, NULL);
 
-	sproc = r_subprocess_newv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
-	if (sproc == NULL) {
-		g_propagate_prefixed_error(
-				error,
-				ierror,
-				"failed to start mkfs.vfat: ");
-		goto out;
-	}
-
-	res = g_subprocess_wait_check(sproc, NULL, &ierror);
+	res = r_subprocess_runv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
 	if (!res) {
 		g_propagate_prefixed_error(
 				error,
@@ -1221,7 +1091,6 @@ out:
 
 static gboolean nor_write_slot(const gchar *image, const gchar *device, GError **error)
 {
-	g_autoptr(GSubprocess) sproc = NULL;
 	GError *ierror = NULL;
 	gboolean res = FALSE;
 	g_autoptr(GPtrArray) args = g_ptr_array_new_full(5, g_free);
@@ -1231,16 +1100,7 @@ static gboolean nor_write_slot(const gchar *image, const gchar *device, GError *
 	g_ptr_array_add(args, g_strdup(device));
 	g_ptr_array_add(args, NULL);
 
-	sproc = r_subprocess_newv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
-	if (sproc == NULL) {
-		g_propagate_prefixed_error(
-				error,
-				ierror,
-				"failed to start flashcp: ");
-		goto out;
-	}
-
-	res = g_subprocess_wait_check(sproc, NULL, &ierror);
+	res = r_subprocess_runv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
 	if (!res) {
 		g_propagate_prefixed_error(
 				error,
@@ -1255,7 +1115,6 @@ out:
 
 static gboolean flash_format_slot(const gchar *device, GError **error)
 {
-	g_autoptr(GSubprocess) sproc = NULL;
 	GError *ierror = NULL;
 	gboolean res = FALSE;
 	g_autoptr(GPtrArray) args = g_ptr_array_new_full(5, g_free);
@@ -1267,16 +1126,7 @@ static gboolean flash_format_slot(const gchar *device, GError **error)
 	g_ptr_array_add(args, g_strdup("0"));
 	g_ptr_array_add(args, NULL);
 
-	sproc = r_subprocess_newv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
-	if (sproc == NULL) {
-		g_propagate_prefixed_error(
-				error,
-				ierror,
-				"failed to start flash_erase: ");
-		goto out;
-	}
-
-	res = g_subprocess_wait_check(sproc, NULL, &ierror);
+	res = r_subprocess_runv(args, G_SUBPROCESS_FLAGS_NONE, &ierror);
 	if (!res) {
 		g_propagate_prefixed_error(
 				error,
@@ -1616,7 +1466,7 @@ static gboolean img_to_ubivol_handler(RaucImage *image, RaucSlot *dest_slot, con
 
 	/* open */
 	g_message("opening slot device %s", dest_slot->device);
-	outstream = open_slot_device(dest_slot, &out_fd, &ierror);
+	outstream = r_open_unix_output_stream(dest_slot->device, &out_fd, &ierror);
 	if (outstream == NULL) {
 		res = FALSE;
 		g_propagate_error(error, ierror);
@@ -1685,7 +1535,7 @@ static gboolean img_to_ubifs_handler(RaucImage *image, RaucSlot *dest_slot, cons
 
 	/* open */
 	g_message("opening slot device %s", dest_slot->device);
-	outstream = open_slot_device(dest_slot, &out_fd, &ierror);
+	outstream = r_open_unix_output_stream(dest_slot->device, &out_fd, &ierror);
 	if (outstream == NULL) {
 		res = FALSE;
 		g_propagate_error(error, ierror);
@@ -2408,7 +2258,7 @@ static gboolean img_to_boot_emmc_handler(RaucImage *image, RaucSlot *dest_slot,
 
 	/* open */
 	g_message("Opening slot device partition %s", part_slot->device);
-	outstream = open_slot_device(part_slot, &out_fd, &ierror);
+	outstream = r_open_unix_output_stream(part_slot->device, &out_fd, &ierror);
 	if (outstream == NULL) {
 		g_propagate_error(error, ierror);
 		res = FALSE;
@@ -2560,7 +2410,6 @@ out:
 
 static gboolean img_to_boot_raw_fallback_handler(RaucImage *image, RaucSlot *dest_slot, const gchar *hook_name, GError **error)
 {
-	gboolean res = FALSE;
 	GError *ierror = NULL;
 	guint64 half_size;
 	gboolean primary_clear;
@@ -2585,21 +2434,21 @@ static gboolean img_to_boot_raw_fallback_handler(RaucImage *image, RaucSlot *des
 		g_set_error(error, R_UPDATE_ERROR, R_UPDATE_ERROR_FAILED,
 				"Region start %"G_GUINT64_FORMAT " is not aligned to the header size %"G_GSIZE_FORMAT,
 				dest_slot->region_start, header_size);
-		goto out;
+		return FALSE;
 	}
 
 	if ((half_size % header_size) != 0) {
 		g_set_error(error, R_UPDATE_ERROR, R_UPDATE_ERROR_FAILED,
 				"Half region size %"G_GUINT64_FORMAT " is not aligned to the header size %"G_GSIZE_FORMAT,
 				half_size, header_size);
-		goto out;
+		return FALSE;
 	}
 
 	if (half_size < (guint64)image->checksum.size) {
 		g_set_error(error, R_UPDATE_ERROR, R_UPDATE_ERROR_FAILED,
 				"Size of image (%"G_GOFFSET_FORMAT ") does not fit to slot size %"G_GUINT64_FORMAT,
 				image->checksum.size, half_size);
-		goto out;
+		return FALSE;
 	}
 
 	g_hash_table_insert(vars, g_strdup("RAUC_BOOT_REGION_START"),
@@ -2609,11 +2458,10 @@ static gboolean img_to_boot_raw_fallback_handler(RaucImage *image, RaucSlot *des
 
 	/* run slot pre install hook if enabled */
 	if (hook_name && image->hooks.pre_install) {
-		res = run_slot_hook_extra_env(hook_name, R_SLOT_HOOK_PRE_INSTALL, image,
-				dest_slot, vars, &ierror);
-		if (!res) {
+		if (!run_slot_hook_extra_env(hook_name, R_SLOT_HOOK_PRE_INSTALL, image,
+				dest_slot, vars, &ierror)) {
 			g_propagate_error(error, ierror);
-			goto out;
+			return FALSE;
 		}
 	}
 
@@ -2629,12 +2477,11 @@ static gboolean img_to_boot_raw_fallback_handler(RaucImage *image, RaucSlot *des
 	 * partition was used to boot and is therefore valid. To avoid ending up with two broken partitions,
 	 * upgrade the primary partition first.
 	 */
-	res = check_if_area_is_clear(dest_slot->device, dest_slot->region_start, header_size, &primary_clear, &ierror);
-	if (!res) {
+	if (!check_if_area_is_clear(dest_slot->device, dest_slot->region_start, header_size, &primary_clear, &ierror)) {
 		g_set_error(error, R_UPDATE_ERROR, R_UPDATE_ERROR_FAILED,
 				"Failed to check area at %"G_GUINT64_FORMAT " on %s",
 				dest_slot->region_start, dest_slot->device);
-		goto out;
+		return FALSE;
 	}
 
 	if (primary_clear)
@@ -2647,27 +2494,25 @@ static gboolean img_to_boot_raw_fallback_handler(RaucImage *image, RaucSlot *des
 
 		if (!clear_boot_switch_partition(dest_slot->device, &pd->partition, &ierror)) {
 			g_propagate_error(error, ierror);
-			goto out;
+			return FALSE;
 		}
 
 		if (!write_boot_switch_partition(image, dest_slot->device, &pd->partition, header_size, &ierror)) {
 			g_propagate_error(error, ierror);
-			goto out;
+			return FALSE;
 		}
 	}
 
 	/* run slot post install hook if enabled */
 	if (hook_name && image->hooks.post_install) {
-		res = run_slot_hook_extra_env(hook_name, R_SLOT_HOOK_POST_INSTALL, image,
-				dest_slot, vars, &ierror);
-		if (!res) {
+		if (!run_slot_hook_extra_env(hook_name, R_SLOT_HOOK_POST_INSTALL, image,
+				dest_slot, vars, &ierror)) {
 			g_propagate_error(error, ierror);
-			goto out;
+			return FALSE;
 		}
 	}
 
-out:
-	return res;
+	return TRUE;
 }
 
 static gboolean img_to_raw_handler(RaucImage *image, RaucSlot *dest_slot, const gchar *hook_name, GError **error)
