@@ -151,6 +151,19 @@ int test_remove(const gchar *dirname, const gchar *filename)
 	return res;
 }
 
+int test_lstat(const gchar *dirname, const gchar *filename, GStatBuf *buf)
+{
+	g_autofree gchar *path = NULL;
+	int res;
+
+	path = g_build_filename(dirname, filename, NULL);
+	g_assert_nonnull(path);
+
+	res = g_lstat(path, buf);
+
+	return res;
+}
+
 gboolean test_rm_tree(const gchar *dirname, const gchar *filename)
 {
 	g_autofree gchar *path = NULL;
@@ -182,19 +195,19 @@ int test_prepare_manifest_file(const gchar *dirname, const gchar *filename, cons
 		rm->hook_name = g_strdup("hook.sh");
 	}
 
-	img = g_new0(RaucImage, 1);
+	if (options->slots) {
+		img = g_new0(RaucImage, 1);
+		img->slotclass = g_strdup("rootfs");
+		img->filename = g_strdup("rootfs.ext4");
+		if (options->hooks)
+			img->hooks.post_install = TRUE;
+		rm->images = g_list_append(rm->images, img);
 
-	img->slotclass = g_strdup("rootfs");
-	img->filename = g_strdup("rootfs.ext4");
-	if (options->hooks)
-		img->hooks.post_install = TRUE;
-	rm->images = g_list_append(rm->images, img);
-
-	img = g_new0(RaucImage, 1);
-
-	img->slotclass = g_strdup("appfs");
-	img->filename = g_strdup("appfs.ext4");
-	rm->images = g_list_append(rm->images, img);
+		img = g_new0(RaucImage, 1);
+		img->slotclass = g_strdup("appfs");
+		img->filename = g_strdup("appfs.ext4");
+		rm->images = g_list_append(rm->images, img);
+	}
 
 	g_assert_true(save_manifest_file(path, rm, NULL));
 
