@@ -428,6 +428,48 @@ counter=42\n\
 	free_manifest(rm);
 }
 
+static void test_manifest_load_details(void)
+{
+	gchar *tmpdir;
+	RaucManifest *rm = NULL;
+	gchar* manifestpath = NULL;
+	gboolean res;
+	GError *error = NULL;
+	RaucImage *test_img = NULL;
+	const gchar *mffile = "\
+[update]\n\
+compatible=FooCorp Super BarBazzer\n\
+version=2015.04-1\n\
+\n\
+[image.rootfs]\n\
+filename=rootfs-default.ext4\n\
+version=2015.04.1\n\
+description=image description\n\
+build=123456789\n\
+";
+
+	tmpdir = g_dir_make_tmp("rauc-XXXXXX", NULL);
+	g_assert_nonnull(tmpdir);
+
+	manifestpath = write_tmp_file(tmpdir, "manifest.raucm", mffile, NULL);
+	g_assert_nonnull(manifestpath);
+
+	g_free(tmpdir);
+
+	res = load_manifest_file(manifestpath, &rm, &error);
+	g_assert_no_error(error);
+	g_assert_true(res);
+
+	g_clear_error(&error);
+	g_free(manifestpath);
+
+	test_img = (RaucImage*)g_list_nth_data(rm->images, 0);
+	/* image details are currently ignored during parsing */
+	g_assert_nonnull(test_img);
+
+	free_manifest(rm);
+}
+
 static void test_manifest_invalid_hook_name(void)
 {
 	g_autofree gchar *tmpdir;
@@ -681,6 +723,8 @@ int main(int argc, char *argv[])
 {
 	setlocale(LC_ALL, "C");
 
+	g_assert(g_setenv("GIO_USE_VFS", "local", TRUE));
+
 	g_test_init(&argc, &argv, NULL);
 
 	r_context_conf()->certpath = g_strdup("test/openssl-ca/rel/release-1.cert.pem");
@@ -696,6 +740,7 @@ int main(int argc, char *argv[])
 	g_test_add_func("/manifest/load_variants", test_manifest_load_variants);
 	g_test_add_func("/manifest/load_adaptive", test_manifest_load_adaptive);
 	g_test_add_func("/manifest/load_meta", test_manifest_load_meta);
+	g_test_add_func("/manifest/load_details", test_manifest_load_details);
 	g_test_add_func("/manifest/invalid_hook_name", test_manifest_invalid_hook_name);
 	g_test_add_func("/manifest/missing_hook_name", test_manifest_missing_hook_name);
 	g_test_add_func("/manifest/missing_image_size", test_manifest_missing_image_size);
